# Dollar Sign Not Trigger

I have $3.00 and you have $5.00.

# Dollar Sign Escape

$E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j$

# Dollar Sign Escaped Escape

\3+3

# Dollar Double escaped escape

\$3+3$

# Use Dollar sign

\$3.00 + \$5.00 = \$8.00

# Keep equations separate

3+3
\(3+3) \3+3

# Equations

E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j
E(\mathbf{v}, \mathbf{h}) = -\sum_{i,j}w_{ij}v_i h_j - \sum_i b_i v_i - \sum_j c_j h_j

- Here are some more equations:

  \begin{align} p(v_i=1|\mathbf{h}) & = \sigma\left(\sum_j w_{ij}h_j + b_i\right) \\ p(h_j=1|\mathbf{v}) & = \sigma\left(\sum_i w_{ij}v_i + c_j\right) \end{align}

- Inline equations: p(x|y) = \frac{p(y|x)p(x)}{p(y)}
  , p(x|y) = \frac{p(y|x)p(x)}{p(y)}
  .

# Code

`$$ \begin{align} p(v_i=1|\mathbf{h}) & = \sigma\left(\sum_j w_{ij}h_j + b_i\right) \\ p(h_j=1|\mathbf{v}) & = \sigma\left(\sum_i w_{ij}v_i + c_j\right) \end{align} $$`

# Indented Code

    $$
        \begin{align}
            p(v_i=1|\mathbf{h}) & = \sigma\left(\sum_j w_{ij}h_j + b_i\right) \\
            p(h_j=1|\mathbf{v}) & = \sigma\left(\sum_i w_{ij}v_i + c_j\right)
        \end{align}
    $$